@@ -79,7 +79,7 @@ def get_code(token_type):
 
 class SpellCheckPlugin:
     name = "flake8-spellcheck"
-    version = "0.16.0"
+    version = "0.18.0"
 
     def __init__(self, tree, filename="(none)", file_tokens=None):
         self.file_tokens = file_tokens
@@ -166,6 +166,8 @@ class SpellCheckPlugin:
         elif (
             token_info.type == tokenize.COMMENT
             and "comments" in self.spellcheck_targets
+            # ignore flake8 pragma comments
+            and token_info.string.lstrip("#").split()[0] != "noqa:"
         ):
             value = token_info.string.lstrip("#")
         else:
